************
Installation
************

Requirements
============

EclipsingBinaries has the following requirements:

- astropy>=6.0.0
- astroquery>=0.4.6
- ccdproc>=2.4.0
- matplotlib>=3.5.1
- numpy>=1.22.3
- pandas>=1.4.2
- PyAstronomy>=0.18.1
- scipy>=1.9.3
- statsmodels>=0.13.5
- tqdm>=4.64.1
- numba>=0.57.0
- seaborn>=0.12.2
- pyia>=1.41
- photutils>=1.8.0


Installing EclipsingBinaries
============================

To install ccdproc with `pip <https://pip.pypa.io/en/latest/>`_, simply run::

    pip install EclipsingBinaries

Updating
--------

To update to the latest versions, simply run::

    pip install --upgrade EclipsingBinaries

And to install a specified version, simply run::

    pip install --upgrade EclipsingBinaries==[version]
